Package: shinyjs
Title: Easily Improve the User Experience of Your Shiny Apps in Seconds
Version: 2.1.0
Authors@R: person("Dean", "Attali", 
    email = "daattali@gmail.com",
    role = c("aut", "cre"),
    comment= c(ORCID="0000-0002-5645-3493"))
Description: Perform common useful JavaScript operations in Shiny apps that will
    greatly improve your apps without having to know any JavaScript. Examples
    include: hiding an element, disabling an input, resetting an input back to
    its original value, delaying code execution by a few seconds, and many more
    useful functions for both the end user and the developer. 'shinyjs' can also
    be used to easily call your own custom JavaScript functions from R.
URL: https://deanattali.com/shinyjs/
BugReports: https://github.com/daattali/shinyjs/issues
Depends: R (>= 3.1.0)
Imports: digest (>= 0.6.8), jsonlite, shiny (>= 1.0.0)
Suggests: htmltools (>= 0.2.9), knitr (>= 1.7), rmarkdown, shinyAce,
        shinydisconnect, testthat (>= 0.9.1)
License: MIT + file LICENSE
VignetteBuilder: knitr
RoxygenNote: 7.1.1
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2021-12-21 11:32:22 UTC; Dean-X1C
Author: Dean Attali [aut, cre] (<https://orcid.org/0000-0002-5645-3493>)
Maintainer: Dean Attali <daattali@gmail.com>
Repository: CRAN
Date/Publication: 2021-12-23 10:10:02 UTC
Built: R 4.5.2; ; 2026-04-22 10:15:52 UTC; unix
