Package: shinyjs
Title: Easily Improve the User Experience of Your Shiny Apps in Seconds
Version: 0.9
Authors@R: person("Dean", "Attali", email = "daattali@gmail.com",
    role = c("aut", "cre"))
Description: Perform common useful JavaScript operations in Shiny apps that will
    greatly improve your apps without having to know any JavaScript. Examples
    include: hiding an element, disabling an input, resetting an input back to
    its original value, delaying code execution by a few seconds, and many more
    useful functions for both the end user and the developer. 'shinyjs' can also
    be used to easily call your own custom JavaScript functions from R.
URL: http://deanattali.com/shinyjs
BugReports: https://github.com/daattali/shinyjs/issues
Depends: R (>= 3.1.0)
Imports: digest (>= 0.6.8), htmltools (>= 0.2.6), jsonlite, miniUI (>=
        0.1.1), shiny (>= 0.11.1), stats
Suggests: knitr (>= 1.7), rmarkdown, rstudioapi (>= 0.5), shinyAce,
        testthat (>= 0.9.1), V8 (>= 0.6)
License: MIT + file LICENSE
SystemRequirements: pandoc with https support
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2016-12-26 06:51:27 UTC; Dean
Author: Dean Attali [aut, cre]
Maintainer: Dean Attali <daattali@gmail.com>
Repository: CRAN
Date/Publication: 2016-12-26 10:34:31
Built: R 3.3.2; ; 2017-05-02 13:10:58 UTC; windows
